@@ -3,7 +3,6 @@
 
 import pathlib
 import shutil
-import subprocess
 
 from plinth import action_utils
 from plinth.actions import privileged
@@ -28,9 +27,9 @@ def create_library(name: str):
     calibre.validate_library_name(name)
     library = LIBRARIES_PATH / name
     library.mkdir(mode=0o755)  # Raise exception if already exists
-    subprocess.call(
+    action_utils.run(
         ['calibredb', '--with-library', library, 'list_categories'],
-        stdout=subprocess.DEVNULL)
+        check=False)
 
     # Force systemd StateDirectory= logic to assign proper ownership to the
     # DynamicUser=
