@@ -2,15 +2,23 @@
 """App component for other apps to manage their STUN/TURN server configuration.
 """
 
-from __future__ import annotations  # Can be removed in Python 3.10
-
+import base64
+import hashlib
+import hmac
 import json
 import re
 from dataclasses import dataclass, field
+from time import time
+from typing import ClassVar, Iterable
 
 from plinth import app
 
-TURN_URI_REGEX = r'(stun|turn):(.*):([0-9]{4})\?transport=(tcp|udp)'
+TURN_REST_TTL = 24 * 3600
+
+TURN_REST_USER = 'fbxturnuser'
+
+TURN_URI_REGEX = \
+    r'(stun:(.*):([0-9]{4}))|(turn:(.*):([0-9]{4})\?transport=(tcp|udp))'
 
 
 @dataclass
@@ -28,16 +36,17 @@ class TurnConfiguration:
     that must be used by a STUN/TURN client after advice from the server.
 
     """
-    domain: str = None
+    domain: str | None = None
     uris: list[str] = field(default_factory=list)
-    shared_secret: str = None
+    shared_secret: str | None = None
 
     def __post_init__(self):
         """Generate URIs after object initialization if necessary."""
         if self.domain and not self.uris:
             self.uris = [
-                f'{typ}:{self.domain}:3478?transport={transport}'
-                for typ in ['stun', 'turn'] for transport in ['tcp', 'udp']
+                f'stun:{self.domain}:3478',
+                f'turn:{self.domain}:3478?transport=tcp',
+                f'turn:{self.domain}:3478?transport=udp'
             ]
 
     def to_json(self) -> str:
@@ -52,7 +61,33 @@ class TurnConfiguration:
     def validate_turn_uris(turn_uris: list[str]) -> bool:
         """Return whether the given TURN URI is valid."""
         pattern = re.compile(TURN_URI_REGEX)
-        return all(map(pattern.match, turn_uris))
+        return all(map(pattern.fullmatch, turn_uris))
+
+
+@dataclass
+class UserTurnConfiguration(TurnConfiguration):
+    """Data class to hold per-user TURN server configuration.
+
+    username is a string to identify a specific user and is related to
+    the credential.
+
+    credential is a string generated for this user that must be used
+    by a server to be accepted by Coturn server. It is generated for
+    each user separately upon request and will expire after a set
+    time.
+
+    """
+    username: str | None = None
+    credential: str | None = None
+
+    def to_json(self) -> str:
+        """Return a JSON representation of the configuration."""
+        return json.dumps({
+            'domain': self.domain,
+            'uris': self.uris,
+            'username': self.username,
+            'credential': self.credential
+        })
 
 
 class TurnConsumer(app.FollowerComponent):
@@ -68,7 +103,7 @@ class TurnConsumer(app.FollowerComponent):
 
     """
 
-    _all = {}
+    _all: ClassVar[dict[str, 'TurnConsumer']] = {}
 
     def __init__(self, component_id):
         """Initialize the component.
@@ -81,7 +116,7 @@ class TurnConsumer(app.FollowerComponent):
         self._all[component_id] = self
 
     @classmethod
-    def list(cls) -> list[TurnConsumer]:  # noqa
+    def list(cls) -> Iterable['TurnConsumer']:
         """Return a list of all Coturn components."""
         return cls._all.values()
 
@@ -96,3 +131,29 @@ class TurnConsumer(app.FollowerComponent):
         """Return current coturn configuration."""
         from plinth.modules import coturn
         return coturn.get_config()
+
+
+class TurnTimeLimitedConsumer(TurnConsumer):
+    """Component to manage coturn configuration with time-limited
+    credential.
+
+    This component will generate a new credential upon each request,
+    which will expire after 1 day. The shared secret is used to
+    generate the credential, but is not provided in the configuration.
+
+    """
+
+    def get_configuration(self) -> UserTurnConfiguration:
+        """Return user coturn configuration."""
+        from plinth.modules import coturn
+        static_config = coturn.get_config()
+        timestamp = int(time()) + TURN_REST_TTL
+        username = str(timestamp) + ':' + TURN_REST_USER
+        credential = None
+        if static_config.shared_secret:
+            digest = hmac.new(bytes(static_config.shared_secret, 'utf-8'),
+                              bytes(username, 'utf-8'), hashlib.sha1).digest()
+            credential = base64.b64encode(digest).decode()
+
+        return UserTurnConfiguration(static_config.domain, static_config.uris,
+                                     None, username, credential)
