@@ -1,9 +1,8 @@
 # SPDX-License-Identifier: AGPL-3.0-or-later
-"""
-FreedomBox app to configure Mumble server.
-"""
+"""FreedomBox app to configure Mumble server."""
 
 import pathlib
+from typing import Iterator
 
 from django.urls import reverse_lazy
 from django.utils.translation import gettext_lazy as _
@@ -107,7 +106,8 @@ class MumbleApp(app_module.App):
         if 'mumble-server' not in packages:
             return False
 
-        # Allow upgrades within 1.3.*
+        # Allow upgrades from 1.3.4-1 (bullseye) to 1.3.4-4 (bookworm) but not
+        # to 1.5.735 (trixie) and beyond.
         package = packages['mumble-server']
         if Version(package['new_version']) > Version('1.4~'):
             return False
@@ -123,7 +123,7 @@ class MumbleApp(app_module.App):
         return results
 
 
-def get_available_domains():
+def get_available_domains() -> Iterator[str]:
     """Return an iterator with all domains able to have a certificate."""
     return (domain.name for domain in names.components.DomainName.list()
             if domain.domain_type.can_have_certificate)
