@@ -1,11 +1,8 @@
 # SPDX-License-Identifier: AGPL-3.0-or-later
+"""Application manifest for RSS-Bridge."""
 
 from django.utils.translation import gettext_lazy as _
 
-"""
-Application manifest for RSS-Bridge.
-"""
-
 clients = [{
     'name': _('RSS-Bridge'),
     'platforms': [{
@@ -14,8 +11,6 @@ clients = [{
     }]
 }]
 
-backup = {
-        'data': {
-            'files': ['/etc/rss-bridge/is_public']
-        }
-}
+backup = {'data': {'files': ['/etc/rss-bridge/is_public']}}
+
+tags = [_('Feed generator'), _('News'), _('RSS'), _('ATOM')]
