@@ -4,6 +4,7 @@ Functional, browser based tests for snapshot app.
 """
 
 import pytest
+
 from plinth.tests import functional
 
 pytestmark = [pytest.mark.system, pytest.mark.snapshot]
@@ -64,16 +65,17 @@ def _delete_all(browser):
     delete_button = browser.find_by_name('delete_selected').first
     if not delete_button['disabled']:
         browser.find_by_id('select-all').check()
-        functional.submit(browser, delete_button)
+        functional.submit(browser, element=delete_button)
 
         confirm_button = browser.find_by_name('delete_confirm')
         if confirm_button:  # Only if redirected to confirm page
-            functional.submit(browser, confirm_button)
+            functional.submit(browser, element=confirm_button)
 
 
 def _create_snapshot(browser):
     functional.visit(browser, '/plinth/sys/snapshot/manage/')
-    functional.submit(browser)  # Click on 'Create Snapshot'
+    create_button = browser.find_by_name('create').first
+    functional.submit(browser, element=create_button)
 
 
 def _get_count(browser):
@@ -102,7 +104,7 @@ def _set_configuration(browser, free_space, timeline_enabled, software_enabled,
     browser.find_by_name('weekly_limit').fill(weekly)
     browser.find_by_name('monthly_limit').fill(monthly)
     browser.find_by_name('yearly_limit').fill(yearly)
-    functional.submit(browser)
+    functional.submit(browser, form_class='form-configuration')
 
 
 def _get_configuration(browser):
